# CausalDisco 🪩

Baseline algorithms and analytics tools for Causal Discovery.

### Baseline Algorithms
Find the following baseline algorithms in __CausalDisco/baselines.py__
- R²-SortnRegress
- Var-SortnRegress

### Analytics tools
Find the following analytics tools in __CausalDisco/analytics.py__
- R²-sortability
- Var-sortability
- order_alignment

### Sources
If you find our algorithms useful please consider citing
```
@article{reisach2021beware,
  title={Beware of the Simulated DAG! Causal Discovery Benchmarks May Be Easy to Game},
  author={Reisach, Alexander G. and Seiler, Christof and Weichwald, Sebastian},
  journal={Advances in Neural Information Processing Systems},
  volume={34},
  year={2021}
}

@article{reisach2023simple,
  title={Simple Sorting Criteria Help Find the Causal Order in Additive Noise Models},
  author={Reisach, Alexander G. and Tami, Myriam and Seiler, Christof and Chambaz, Antoine and Weichwald, Sebastian},
  journal={arXiv preprint arXiv:2303.18211},
  year={2023}
}
```